@@ -7,15 +7,15 @@
 
 #include "maildir.h"
 
-#include <collectiondeletejob.h>
-#include <collectionfetchjob.h>
-#include <itemdeletejob.h>
-#include <itemfetchjob.h>
-#include <itemfetchscope.h>
-#include <itemmodifyjob.h>
+#include <Akonadi/CollectionDeleteJob>
+#include <Akonadi/CollectionFetchJob>
+#include <Akonadi/ItemDeleteJob>
+#include <Akonadi/ItemFetchJob>
+#include <Akonadi/ItemFetchScope>
+#include <Akonadi/ItemModifyJob>
 
 #include "akonadi/kmime/messageparts.h"
-#include <kmime/kmime_message.h>
+#include <KMime/KMimeMessage>
 
 #define WAIT_TIME 100
 
