@@ -4,11 +4,10 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MESSAGETEST_TEST_H
-#define MESSAGETEST_TEST_H
+#pragma once
 
+#include <KMime/KMimeMessage>
 #include <QObject>
-#include <kmime/kmime_message.h>
 
 class MessageTest : public QObject
 {
@@ -20,4 +19,3 @@ private:
     KMime::Message::Ptr readAndParseMail(const QString &mailFile) const;
 };
 
-#endif
