@@ -9,12 +9,12 @@
 #include <KProcess>
 #include <QDebug>
 
-#include <agentinstance.h>
-#include <agentinstancecreatejob.h>
-#include <agentmanager.h>
-#include <agenttype.h>
+#include <Akonadi/AgentInstance>
+#include <Akonadi/AgentInstanceCreateJob>
+#include <Akonadi/AgentManager>
+#include <Akonadi/AgentType>
+#include <akonadi/qtest_akonadi.h>
 #include <control.h>
-#include <qtest_akonadi.h>
 //#include <localfolders.h>
 
 #define TIMEOUT_SECONDS 20
