@@ -9,15 +9,15 @@
 #include <QMutex>
 #include <QObject>
 
-#include <AkonadiCore/gidextractorinterface.h>
-#include <AkonadiCore/itemserializerplugin.h>
+#include <Akonadi/GidExtractorInterface>
+#include <Akonadi/ItemSerializerPlugin>
 
 namespace Akonadi
 {
 /**
  * Levare QString implicit sharing to decrease memory consumption.
  *
- * This class is thread safe. Apparenlty required for usage in
+ * This class is thread safe. Apparently required for usage in
  * legacy KRes compat bridges.
  */
 class StringPool
