@@ -8,39 +8,38 @@
 
 #include <QDataStream>
 
-#include <attributefactory.h>
+#include <Akonadi/AttributeFactory>
 
 using namespace Akonadi;
 
 /**
   @internal
 */
-class AddressAttribute::Private
+class Akonadi::AddressAttributePrivate
 {
 public:
+    bool mDSN = false;
     QString mFrom;
     QStringList mTo;
     QStringList mCc;
     QStringList mBcc;
 };
 
-AddressAttribute::AddressAttribute(const QString &from, const QStringList &to, const QStringList &cc, const QStringList &bcc)
-    : d(new Private)
+AddressAttribute::AddressAttribute(const QString &from, const QStringList &to, const QStringList &cc, const QStringList &bcc, bool dsn)
+    : d(new AddressAttributePrivate)
 {
     d->mFrom = from;
     d->mTo = to;
     d->mCc = cc;
     d->mBcc = bcc;
+    d->mDSN = dsn;
 }
 
-AddressAttribute::~AddressAttribute()
-{
-    delete d;
-}
+AddressAttribute::~AddressAttribute() = default;
 
 AddressAttribute *AddressAttribute::clone() const
 {
-    return new AddressAttribute(d->mFrom, d->mTo, d->mCc, d->mBcc);
+    return new AddressAttribute(d->mFrom, d->mTo, d->mCc, d->mBcc, d->mDSN);
 }
 
 QByteArray AddressAttribute::type() const
@@ -58,6 +57,7 @@ QByteArray AddressAttribute::serialized() const
     serializer << d->mTo;
     serializer << d->mCc;
     serializer << d->mBcc;
+    serializer << d->mDSN;
     return serializedData;
 }
 
@@ -69,6 +69,9 @@ void AddressAttribute::deserialize(const QByteArray &data)
     deserializer >> d->mTo;
     deserializer >> d->mCc;
     deserializer >> d->mBcc;
+    if (!deserializer.atEnd()) {
+        deserializer >> d->mDSN;
+    }
 }
 
 QString AddressAttribute::from() const
@@ -111,6 +114,21 @@ void AddressAttribute::setBcc(const QStringList &bcc)
     d->mBcc = bcc;
 }
 
+bool AddressAttribute::deliveryStatusNotification() const
+{
+    return d->mDSN;
+}
+
+bool AddressAttribute::operator==(const AddressAttribute &other) const
+{
+    return d->mDSN == other.deliveryStatusNotification() && d->mBcc == other.bcc() && d->mTo == other.to() && d->mCc == other.cc() && d->mFrom == other.from();
+}
+
+void AddressAttribute::setDeliveryStatusNotification(bool b)
+{
+    d->mDSN = b;
+}
+
 // Register the attribute when the library is loaded.
 namespace
 {
