@@ -14,11 +14,11 @@
 #include <KLocalizedString>
 #include <KMessageBox>
 
-#include <agentmanager.h>
-#include <entitytreemodel.h>
-#include <itemdeletejob.h>
-#include <itemfetchjob.h>
-#include <kmime/kmime_message.h>
+#include <Akonadi/AgentManager>
+#include <Akonadi/EntityTreeModel>
+#include <Akonadi/ItemDeleteJob>
+#include <Akonadi/ItemFetchJob>
+#include <KMime/KMimeMessage>
 using namespace Akonadi;
 EmptyTrashCommand::EmptyTrashCommand(const QAbstractItemModel *model, QObject *parent)
     : CommandBase(parent)
