@@ -8,10 +8,10 @@
 #include "markascommand.h"
 #include "akonadi_mime_debug.h"
 #include "util_p.h"
-#include <collectionfetchjob.h>
-#include <itemfetchjob.h>
-#include <itemfetchscope.h>
-#include <itemmodifyjob.h>
+#include <Akonadi/CollectionFetchJob>
+#include <Akonadi/ItemFetchJob>
+#include <Akonadi/ItemFetchScope>
+#include <Akonadi/ItemModifyJob>
 
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -57,10 +57,7 @@ MarkAsCommand::MarkAsCommand(Akonadi::MessageStatus targetStatus, const Akonadi:
     d->mRecursive = recursive;
 }
 
-MarkAsCommand::~MarkAsCommand()
-{
-    delete d;
-}
+MarkAsCommand::~MarkAsCommand() = default;
 
 void MarkAsCommand::slotCollectionFetchDone(KJob *job)
 {
@@ -113,9 +110,9 @@ void MarkAsCommand::slotFetchDone(KJob *job)
         markMessages();
     }
     if (d->mFolderListJobCount > 0) {
-        auto job = new Akonadi::ItemFetchJob(d->mFolders[d->mFolderListJobCount - 1], parent());
-        job->fetchScope().setAncestorRetrieval(Akonadi::ItemFetchScope::Parent);
-        connect(job, &Akonadi::ItemFetchJob::result, this, &MarkAsCommand::slotFetchDone);
+        auto fetchJob = new Akonadi::ItemFetchJob(d->mFolders[d->mFolderListJobCount - 1], parent());
+        fetchJob->fetchScope().setAncestorRetrieval(Akonadi::ItemFetchScope::Parent);
+        connect(fetchJob, &Akonadi::ItemFetchJob::result, this, &MarkAsCommand::slotFetchDone);
     }
 }
 
@@ -124,7 +121,9 @@ void MarkAsCommand::execute()
     if (d->mRecursive && !d->mFolders.isEmpty()) {
         if (KMessageBox::questionYesNo(qobject_cast<QWidget *>(parent()),
                                        i18n("Are you sure you want to mark all messages in this folder and all its subfolders?"),
-                                       i18n("Mark All Recursively"))
+                                       i18n("Mark All Recursively"),
+                                       KGuiItem(i18nc("@action:button", "Mark All")),
+                                       KStandardGuiItem::cancel())
             == KMessageBox::Yes) {
             auto job = new Akonadi::CollectionFetchJob(d->mFolders.constFirst());
             connect(job, &Akonadi::CollectionFetchJob::result, this, &MarkAsCommand::slotCollectionFetchDone);
