@@ -8,12 +8,16 @@
 
 #include "akonadi-mime_export.h"
 
-#include <attribute.h>
+#include <Akonadi/Attribute>
 
 #include <QByteArray>
 
+#include <memory>
+
 namespace Akonadi
 {
+class MessageFolderAttributePrivate;
+
 /**
   Message folder information. Used eg. by mail clients to decide how to display the content of such collections
   @since 4.4
@@ -57,8 +61,7 @@ public:
     void deserialize(const QByteArray &data) override;
 
 private:
-    class Private;
-    Private *const d;
+    std::unique_ptr<MessageFolderAttributePrivate> const d;
 };
 }
 
