@@ -7,37 +7,34 @@
 #include "messagemodel.h"
 #include "messageparts.h"
 
-#include <entitytreemodel.h>
-#include <itemfetchscope.h>
-#include <monitor.h>
-#include <session.h>
+#include <Akonadi/ItemFetchScope>
+#include <Akonadi/Monitor>
+#include <Akonadi/Session>
 
-#include <kmime/kmime_message.h>
+#include <KMime/KMimeMessage>
 
 #include <KLocalizedString>
 
-#include <QLocale>
 #include <KFormat>
+#include <QLocale>
 
 #include <array>
 
-typedef KMime::Message::Ptr MessagePtr;
+using MessagePtr = KMime::Message::Ptr;
 
 using namespace Akonadi;
 
-namespace {
-
+namespace
+{
 struct HeaderName {
     const char *desc;
     const char *name;
 };
-constexpr std::array<HeaderName, 5> headers = {{
-    {I18NC_NOOP("@title:column, message (e.g. email) subject", "Subject")},
-    {I18NC_NOOP("@title:column, sender of message (e.g. email)", "Sender")},
-    {I18NC_NOOP("@title:column, receiver of message (e.g. email)", "Receiver")},
-    {I18NC_NOOP("@title:column, message (e.g. email) timestamp", "Date")},
-    {I18NC_NOOP("@title:column, message (e.g. email) size", "Size")}
-}};
+constexpr std::array<HeaderName, 5> headers = {{{I18NC_NOOP("@title:column, message (e.g. email) subject", "Subject")},
+                                                {I18NC_NOOP("@title:column, sender of message (e.g. email)", "Sender")},
+                                                {I18NC_NOOP("@title:column, receiver of message (e.g. email)", "Receiver")},
+                                                {I18NC_NOOP("@title:column, message (e.g. email) timestamp", "Date")},
+                                                {I18NC_NOOP("@title:column, message (e.g. email) size", "Size")}}};
 
 }
 
