@@ -6,12 +6,11 @@
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef AKONADI_KMIME_MESSAGESTATUS_H
-#define AKONADI_KMIME_MESSAGESTATUS_H
-
-#include <QSet>
+#pragma once
 
 #include "akonadi-mime_export.h"
+#include <QDebug>
+#include <QSet>
 
 class QString;
 
@@ -416,4 +415,4 @@ private:
 };
 } // namespace Akonadi
 
-#endif
+AKONADI_MIME_EXPORT QDebug operator<<(QDebug d, const Akonadi::MessageStatus &t);
