@@ -8,8 +8,8 @@
 #include "movecommand.h"
 #include "util_p.h"
 
-#include <itemmovejob.h>
-#include <itemdeletejob.h>
+#include <Akonadi/ItemDeleteJob>
+#include <Akonadi/ItemMoveJob>
 using namespace Akonadi;
 
 class Akonadi::MoveCommandPrivate
@@ -31,10 +31,7 @@ MoveCommand::MoveCommand(const Akonadi::Collection &destFolder, const Akonadi::I
     d->mMessages = msgList;
 }
 
-MoveCommand::~MoveCommand()
-{
-    delete d;
-}
+MoveCommand::~MoveCommand() = default;
 
 void MoveCommand::execute()
 {
@@ -43,10 +40,10 @@ void MoveCommand::execute()
         return;
     }
     if (d->mDestFolder.isValid()) {
-        auto *job = new Akonadi::ItemMoveJob(d->mMessages, d->mDestFolder, this);
+        auto job = new Akonadi::ItemMoveJob(d->mMessages, d->mDestFolder, this);
         connect(job, &Akonadi::ItemMoveJob::result, this, &MoveCommand::slotMoveResult);
     } else {
-        auto *job = new Akonadi::ItemDeleteJob(d->mMessages, this);
+        auto job = new Akonadi::ItemDeleteJob(d->mMessages, this);
         connect(job, &Akonadi::ItemDeleteJob::result, this, &MoveCommand::slotMoveResult);
     }
 }
