@@ -5,13 +5,14 @@
     SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
-#ifndef MOVECOMMAND_H
-#define MOVECOMMAND_H
+#pragma once
 
 #include "akonadi-mime_export.h"
 #include "commandbase.h"
-#include <collection.h>
-#include <item.h>
+#include <Akonadi/Collection>
+#include <Akonadi/Item>
+
+#include <memory>
 
 class KJob;
 namespace Akonadi
@@ -29,7 +30,6 @@ private Q_SLOTS:
     void slotMoveResult(KJob *job);
 
 private:
-    MoveCommandPrivate *const d;
+    std::unique_ptr<MoveCommandPrivate> const d;
 };
 }
-#endif // MOVECOMMAND_H
