@@ -1,21 +1,19 @@
 /*
-    SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef NEWMAILNOTIFIERATTRIBUTE_H
-#define NEWMAILNOTIFIERATTRIBUTE_H
+#pragma once
 
 #include "akonadi-mime_export.h"
 
-#include <AkonadiCore/Attribute>
+#include <Akonadi/Attribute>
 
-#include <QScopedPointer>
+#include <memory>
 
 namespace Akonadi
 {
-
 class NewMailNotifierAttributePrivate;
 class AKONADI_MIME_EXPORT NewMailNotifierAttribute : public Akonadi::Attribute
 {
@@ -35,8 +33,7 @@ public:
 
 private:
     friend class NewMailNotifierAttributePrivate;
-    QScopedPointer<NewMailNotifierAttributePrivate> const d;
+    std::unique_ptr<NewMailNotifierAttributePrivate> const d;
 };
 }
 
-#endif // NEWMAILNOTIFIERATTRIBUTE_H
