@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,11 +7,10 @@
 #include "pop3resourceattribute.h"
 
 #include <QByteArray>
-#include <QIODevice>
 #include <QDataStream>
+#include <QIODevice>
 namespace Akonadi
 {
-
 class Pop3ResourceAttributePrivate
 {
 public:
@@ -27,7 +26,7 @@ Pop3ResourceAttribute::~Pop3ResourceAttribute() = default;
 
 Pop3ResourceAttribute *Pop3ResourceAttribute::clone() const
 {
-    auto *attr = new Pop3ResourceAttribute();
+    auto attr = new Pop3ResourceAttribute();
     attr->setPop3AccountName(pop3AccountName());
     return attr;
 }
