@@ -7,9 +7,9 @@
 #pragma once
 
 #include "akonadi-mime_export.h"
-#include <AkonadiCore/Attribute>
+#include <Akonadi/Attribute>
 
-#include <QScopedPointer>
+#include <memory>
 
 namespace Akonadi
 {
@@ -33,6 +33,6 @@ public:
 
 private:
     friend class Pop3ResourceAttributePrivate;
-    QScopedPointer<Pop3ResourceAttributePrivate> const d;
+    std::unique_ptr<Pop3ResourceAttributePrivate> const d;
 };
 }
