@@ -8,18 +8,18 @@
 
 #include "removeduplicatesjob.h"
 #include "akonadi_mime_debug.h"
-#include <itemdeletejob.h>
-#include <itemfetchjob.h>
-#include <itemfetchscope.h>
+#include <Akonadi/ItemDeleteJob>
+#include <Akonadi/ItemFetchJob>
+#include <Akonadi/ItemFetchScope>
 
-#include <kmime/kmime_message.h>
+#include <KMime/KMimeMessage>
 
 #include <KLocalizedString>
 
-class Q_DECL_HIDDEN Akonadi::RemoveDuplicatesJob::Private
+class Akonadi::RemoveDuplicatesJobPrivate
 {
 public:
-    Private(RemoveDuplicatesJob *parent)
+    explicit RemoveDuplicatesJobPrivate(RemoveDuplicatesJob *parent)
         : mParent(parent)
     {
     }
@@ -147,7 +147,7 @@ using namespace Akonadi;
 
 RemoveDuplicatesJob::RemoveDuplicatesJob(const Akonadi::Collection &folder, QObject *parent)
     : Job(parent)
-    , d(new Private(this))
+    , d(new RemoveDuplicatesJobPrivate(this))
 {
     d->mJobCount = 1;
     d->mFolders << folder;
@@ -155,16 +155,13 @@ RemoveDuplicatesJob::RemoveDuplicatesJob(const Akonadi::Collection &folder, QObj
 
 RemoveDuplicatesJob::RemoveDuplicatesJob(const Akonadi::Collection::List &folders, QObject *parent)
     : Job(parent)
-    , d(new Private(this))
+    , d(new RemoveDuplicatesJobPrivate(this))
 {
     d->mFolders = folders;
     d->mJobCount = d->mFolders.length();
 }
 
-RemoveDuplicatesJob::~RemoveDuplicatesJob()
-{
-    delete d;
-}
+RemoveDuplicatesJob::~RemoveDuplicatesJob() = default;
 
 void RemoveDuplicatesJob::doStart()
 {
