@@ -8,13 +8,17 @@
 
 #pragma once
 
-#include <collection.h>
-#include <job.h>
+#include <Akonadi/Collection>
+#include <Akonadi/Job>
 
 #include "akonadi-mime_export.h"
 
+#include <memory>
+
 namespace Akonadi
 {
+class RemoveDuplicatesJobPrivate;
+
 /**
  * @short Job that finds and removes duplicate messages in given collection
  *
@@ -54,8 +58,8 @@ protected:
     bool doKill() override;
 
 private:
-    class Private;
-    Private *const d;
+    friend class RemoveDuplicatesJobPrivate;
+    std::unique_ptr<RemoveDuplicatesJobPrivate> const d;
 };
 } /* namespace Akonadi */
 
