@@ -4,14 +4,14 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_SPECIALMAILCOLLECTIONS_H
-#define AKONADI_SPECIALMAILCOLLECTIONS_H
+#pragma once
 
 #include "akonadi-mime_export.h"
 
-#include <specialcollections.h>
+#include <Akonadi/SpecialCollections>
 
-namespace Akonadi {
+namespace Akonadi
+{
 class SpecialMailCollectionsPrivate;
 
 /**
@@ -62,15 +62,15 @@ public:
      * the same type in the same resource.
      */
     enum Type {
-        Invalid = -1,    ///< An invalid special collection.
-        Root = 0,        ///< The root collection containing the local folders.
-        Inbox,           ///< The inbox collection.
-        Outbox,          ///< The outbox collection.
-        SentMail,        ///< The sent-mail collection.
-        Trash,           ///< The trash collection.
-        Drafts,          ///< The drafts collection.
-        Templates,       ///< The templates collection.
-        LastType         ///< @internal marker
+        Invalid = -1, ///< An invalid special collection.
+        Root = 0, ///< The root collection containing the local folders.
+        Inbox, ///< The inbox collection.
+        Outbox, ///< The outbox collection.
+        SentMail, ///< The sent-mail collection.
+        Trash, ///< The trash collection.
+        Drafts, ///< The drafts collection.
+        Templates, ///< The templates collection.
+        LastType ///< @internal marker
     };
 
     /**
@@ -131,6 +131,7 @@ public:
     void verifyI18nDefaultCollection(Type type);
 private Q_SLOTS:
     void slotCollectionModified(KJob *job);
+
 private:
     //@cond PRIVATE
     friend class SpecialMailCollectionsPrivate;
@@ -147,4 +148,3 @@ private:
 };
 } // namespace Akonadi
 
-#endif // AKONADI_SPECIALMAILCOLLECTIONS_H
