@@ -9,7 +9,9 @@
 #include "akonadi-mime_export.h"
 #include "specialmailcollections.h"
 
-#include <specialcollectionsrequestjob.h>
+#include <Akonadi/SpecialCollectionsRequestJob>
+
+#include <memory>
 
 namespace Akonadi
 {
@@ -68,7 +70,7 @@ public:
     /**
      * Destroys the special mail collections request job.
      */
-    ~SpecialMailCollectionsRequestJob();
+    ~SpecialMailCollectionsRequestJob() override;
 
     /**
      * Requests a special mail collection of the given @p type in the default resource.
@@ -84,7 +86,7 @@ private:
     //@cond PRIVATE
     friend class SpecialMailCollectionsRequestJobPrivate;
 
-    SpecialMailCollectionsRequestJobPrivate *const d;
+    std::unique_ptr<SpecialMailCollectionsRequestJobPrivate> const d;
     //@endcond
 };
 } // namespace Akonadi
