@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_SPECIALMAILCOLLECTIONSTESTING_P_H
-#define AKONADI_SPECIALMAILCOLLECTIONSTESTING_P_H
+#pragma once
 
 #include "akonadi-mimeprivate_export.h"
 #include "specialmailcollections.h"
@@ -30,4 +29,3 @@ public:
 };
 } // namespace Akonadi
 
-#endif // AKONADI_SPECIALMAILCOLLECTIONSTESTING_H
