@@ -5,25 +5,26 @@
     SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
-#include "util_p.h"
 #include "imapsettings.h"
+#include "util_p.h"
 
-#include <servermanager.h>
+#include <Akonadi/ServerManager>
 #include <QDBusConnection>
 
-#include <assert.h>
 #include "akonadi_mime_debug.h"
-#include <KJobUiDelegate>
 #include <KIO/Job>
+#include <KJobUiDelegate>
+#include <assert.h>
 
-namespace Util {
+namespace Util
+{
 /// Helper to sanely show an error message for a job
 void showJobError(KJob *job)
 {
     assert(job);
     // we can be called from the KJob::kill, where we are no longer a KIO::Job
     // so better safe than sorry
-    auto *kiojob = qobject_cast<KIO::Job *>(job);
+    auto kiojob = qobject_cast<KIO::Job *>(job);
     if (kiojob && kiojob->uiDelegate()) {
         kiojob->uiDelegate()->showErrorMessage();
     } else {
@@ -33,7 +34,7 @@ void showJobError(KJob *job)
 
 OrgKdeAkonadiImapSettingsInterface *createImapSettingsInterface(const QString &ident)
 {
-    //NOTE(Andras): from kmail/util.cpp
+    // NOTE(Andras): from kmail/util.cpp
     return new OrgKdeAkonadiImapSettingsInterface(Akonadi::ServerManager::agentServiceName(Akonadi::ServerManager::Resource, ident),
                                                   QStringLiteral("/Settings"),
                                                   QDBusConnection::sessionBus());
